# UniCeption Information Sharing Blocks

## Currently Supported Information Sharing Architectures

### UniCeptionInfoSharingBase:

- `DifferentialMultiViewCrossAttentionTransformer`
   - `DifferentialMultiViewCrossAttentionTransformerIFR`
- `GlobalAttentionTransformer`
- `MultiViewCrossAttentionTransformer`
   - `MultiViewCrossAttentionTransformerIFR`
- `MultiViewGlobalAttentionTransformer`
   - `MultiViewGlobalAttentionTransformerIFR`
- `MultiViewAlternatingAttentionTransformer`
   - `MultiViewAlternatingAttentionTransformerIFR`

## Developer Guidelines

Please follow the main UniCeption developer guidelines described in `README.md` when contributing to the information sharing blocks. Make sure to test your different implementations and add necessary unit tests.

## Happy Coding!
